import {select, 
        csv, 
        scaleLinear, 
        scaleTime,
        area,
        extent, 
        axisLeft, 
        axisBottom,
        curveBasis,
        format} from 'd3';

const svg = d3.select("svg");

const width = +svg.attr("width");
const height = +svg.attr("height"); //unary +-operator converts string to number

const render = data => {
  const Title = 'World Population';
  const xValue = d => d.year;
  const xAxisLabel = 'Year';
  
  const yValue = d => d.population;
  const yAxisLabel = 'Population';

  
  const margin = {left: 150, top:60, right: 40, bottom:80};
  
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth])
  	;
  
  const yScale = scaleLinear()
  	.domain(extent(data, yValue))
  	.range([ innerHeight, 0])
  	
;
  
  const yAxis = axisLeft(yScale); //returns a function 
  const xAxis = axisBottom(xScale); //returns a function 
  const yAxisTickFormat = n => format('.1s')(n).replace('G', 'B'); 
  const xAxisTickFormat = n => format('')(n); 
  
  const g = svg.append('g')
  .attr('transform', `translate(${margin.left}, ${margin.top})`);
   
    
  g.append('text')
  	.text(Title)
    .attr('x', innerWidth/2)
    .attr('y', -15)
    .attr('text-anchor', 'middle')
    .attr('class', 'graph-title');
  
  //yAxis(g.append('g')); Which is equal to:
  const yAxisGroup =
  g.append('g').call(yAxis.tickSize(-innerWidth).tickFormat(yAxisTickFormat));
  	//.selectAll('.domain, .tick line').remove();
  
  
  yAxisGroup.append('text')
    .attr('class', 'axis-label')
  	//.attr('fill', 'black')
    .attr('x', -innerHeight/2)
    .attr('text-anchor', 'middle')
  	.attr('y', -70)
  	.text(yAxisLabel)
    .attr('transform', `rotate(-90)`);
  //translate(${-100, 0})`);
;

  
  const xAxisGroup =   g.append('g').call(
    xAxis
    .tickSize(-innerHeight)
    .tickFormat(xAxisTickFormat)
  	.tickPadding(10)
  	)
    .attr('transform', `translate(0, ${innerHeight})`);

  xAxisGroup.select('.domain').remove();
  
  xAxisGroup.append('text')
  	.attr('class', 'axis-label')
    .attr('y', 70)
  	.attr('x', innerWidth/2)
  	//.attr('fill', 'black')
  	.text(xAxisLabel);

  const areaGenerator = area()
  	.x(d => xScale(xValue(d)))
  	.y1(d => yScale(yValue(d)))
  	.y0(innerHeight)
  	.curve(curveBasis);
  
 
  g.append('path')
  		.attr('class', 'path-line')
    	.attr('d', areaGenerator(data))
  		;
  

  
};

csv('data.csv').then(data => {
  data.forEach(d=> {

                   ;
  d.year= +d.year;
  d.population = +d.population;  
    
  })
  render(data);
  console.log(data);


})
